"""GLiCID form templates module."""

from jinja2 import Environment, PackageLoader, select_autoescape

from .micromamba import get_envs
from .resources import CPU, GPU, RAM

TEMPLATES = Environment(
    loader=PackageLoader('glicid_spawner'),
    autoescape=select_autoescape(),
)


def options_attrs(username: str) -> dict:
    """Form options attributes."""
    return {
        'username': username,
        'python_envs': get_envs(username),
        'cpu_available': CPU,
        'ram_available': RAM,
        'gpu_available': GPU,
    }


def options_form(username: str) -> str:
    """Render default spawner form."""
    template = TEMPLATES.get_template('interactive.html')
    return template.render(**options_attrs(username))


def options_from_form(formdata) -> dict:
    """Export options from default form."""
    # Resources choices indexes
    i_cpu = int(formdata['cpu'][0])
    i_ram = int(formdata['ram'][0])
    i_gpu = int(formdata['gpu'][0])

    duration = min(
        CPU[i_cpu].max_duration,
        RAM[i_ram].max_duration,
        GPU[i_gpu].max_duration,
    )

    # Export options
    options = {
        'pyenv': formdata['python-env'][0],
        'nprocs': int(CPU[i_cpu].description),
        'memory': RAM[i_ram].description.replace(' ', ''),
        'runtime': f'{duration:02d}:00:00',
    }

    if i_gpu:
        options['gres'] = 'gpu:' + GPU[i_gpu].description.lower()

    return options
